@@ -182,6 +182,7 @@ struct sslCheckOptions
     int ipv4;
     int ipv6;
     int ocspStatus;
+    int ianaNames;
     char cipherstring[65536];
 
     // File Handles...
@@ -192,6 +193,7 @@ struct sslCheckOptions
     struct sockaddr_in serverAddress;
     struct sockaddr_in6 serverAddress6;
     struct timeval timeout;
+    int connect_timeout;
     unsigned int sleep;
 
     // SSL Variables...
